@@ -6,4 +6,4 @@ if TYPE_CHECKING:
 TYO100 = "TYO100: Local import '{module}' only used for type hinting"  # noqa: FS003
 TYO101 = "TYO101: Remote import '{module}' only used for type hinting"  # noqa: FS003
 
-disabled_by_default: 'List[str]' = [TYO101]
+disabled_by_default: 'List[str]' = ['TYO101']
